==> boofcv-ip-multiview-0.39-sources.jar: boofcv/alg/disparity/block/score/DisparitySparseRectifiedScoreBM_S32.java <==
/*
 * Copyright (c) 2011-2020, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.alg.disparity.block.score;

import boofcv.struct.image.ImageGray;
import lombok.Getter;

/**
 * <p>
 * Implementation of {@link DisparitySparseRectifiedScoreBM} that processes integer typed images.
 * </p>
 *
 * @author Peter Abeles
 */
@SuppressWarnings({"MissingOverride"})
public abstract class DisparitySparseRectifiedScoreBM_S32<T extends ImageGray<T>>
		extends DisparitySparseRectifiedScoreBM<int[], T> {
	// Fit scores as a function of disparity. scores[0] = score at disparity of disparityMin
	@Getter protected int[] scoreLtoR; // left to right
	@Getter protected int[] scoreRtoL; // right to left

	protected DisparitySparseRectifiedScoreBM_S32( int radiusX, int radiusY, Class<T> imageType ) {
		super(radiusX, radiusY, imageType);
	}

	@Override
	public void configure( int disparityMin, int disparityRange ) {
		super.configure(disparityMin, disparityRange);
		scoreLtoR = new int[disparityRange];
		scoreRtoL = new int[disparityRange];
	}
}

==> boofcv-ip-multiview-0.43-sources.jar: boofcv/alg/disparity/block/score/DisparitySparseRectifiedScoreBM_S32.java <==
/*
 * Copyright (c) 2021, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.alg.disparity.block.score;

import boofcv.struct.image.ImageGray;
import lombok.Getter;

/**
 * <p>
 * Implementation of {@link DisparitySparseRectifiedScoreBM} that processes integer typed images.
 * </p>
 *
 * @author Peter Abeles
 */
@SuppressWarnings({"MissingOverride", "NullAway.Init"})
public abstract class DisparitySparseRectifiedScoreBM_S32<T extends ImageGray<T>>
		extends DisparitySparseRectifiedScoreBM<int[], T> {
	// Fit scores as a function of disparity. scores[0] = score at disparity of disparityMin
	@Getter protected int[] scoreLtoR; // left to right
	@Getter protected int[] scoreRtoL; // right to left

	protected DisparitySparseRectifiedScoreBM_S32( int radiusX, int radiusY, Class<T> imageType ) {
		super(radiusX, radiusY, imageType);
	}

	@Override
	public void configure( int disparityMin, int disparityRange ) {
		super.configure(disparityMin, disparityRange);
		scoreLtoR = new int[disparityRange];
		scoreRtoL = new int[disparityRange];
	}
}
